# whois
a wrapper for whoisxml

## Usage

### From Shell

``` sh
python whoisxml.py --api <YOUR_WHOISXML_KEY> --ip <IP>

```
### Python Module

``` python
from whoisxml import whoisxmlapi

```

## Installation

``` sh
pip install -r requirements.txt

```